@@ -16,7 +16,6 @@ from .strategy import (
     AwesomeVersionStrategyDescription,
 )
 from .typing import EnsureStrategyIterableType, EnsureStrategyType, VersionType
-from .utils.logger import LOGGER
 from .utils.regex import (
     RE_DIGIT,
     RE_MODIFIER,
@@ -184,7 +183,7 @@ class AwesomeVersion(_AwesomeVersionBase):
         if self.sections >= (idx + 1):
             match = RE_DIGIT.match(self.string.split(".")[idx] or "")
             if match and match.groups():
-                return int(match.group(1))
+                return int(match.group(1) or 0)
         return 0
 
     @staticmethod
@@ -201,18 +200,6 @@ class AwesomeVersion(_AwesomeVersionBase):
                 return result
         return False
 
-    @staticmethod
-    def ensure_strategy(
-        version: str | float | int | AwesomeVersion,
-        strategy: AwesomeVersionStrategy | list[AwesomeVersionStrategy],
-    ) -> AwesomeVersion:
-        """Return a AwesomeVersion object, or raise on creation."""
-        LOGGER.warning(
-            "Using AwesomeVersion.ensure_strategy(version, strategy) is deprecated, "
-            "use AwesomeVersion(version, strategy) instead"
-        )
-        return AwesomeVersion(version, strategy)
-
     @property
     def string(self) -> str:
         """Return a string representaion of the version."""
